clear all

*********************** CWED ENTITLEMENT DATA ******************************

use "data/raw/CWEP_Generosity_Scores_DATASET.dta", clear
rename ISOCODE iso
rename YEAR year
xtset iso year
drop if year>2018

// ipolate 
sort iso year
foreach x in UE_GEN P_GEN UE_RR_S100 UE_RR_C1000 SP_RR_S100 SP_RR_C1000 MP_RR_S100 MP_RR_C1000 UE_DUR_40 PEN_DUR {
	by iso: ipolate `x' year, gen(`x'_ipo)
	replace `x' = `x'_ipo if mi(`x')
}

// summary generosity indicators
rename UE_GEN uegen 
rename P_GEN pengen 

// replacement rates 
gen uegen_rr = UE_RR_S100+UE_RR_C1000
gen pengen_rr = SP_RR_S100+SP_RR_C1000+MP_RR_S100+MP_RR_C1000 

// benefit duration
gen uegen_dur = log(UE_DUR_40)
gen pengen_dur = PEN_DUR

// visible changes
gstats transform (standardize) uegen_rr uegen_dur pengen_rr pengen_dur, replace

gen uegen_vis = uegen_dur + uegen_rr 
gen pengen_vis = pengen_dur + pengen_rr 

// clean, reshape, and save
local CWED_list uegen pengen uegen_vis pengen_vis 
keep iso year `CWED_list'
reshape wide `CWED_list',i(iso) j(year)
save "data/processed/cwed_processed.dta", replace



*********************** WELFARE REFORM EVENT DATA ******************************

use "data/raw/welfare_state_reform_events.dta", clear
sort country v2year v3month v4day
mvdecode v2year v3month v4day , mv(-99)

// prepare time and country identifiers
replace v3month = 6 if mi(v3month) & !mi(v2year)
replace country = "United Kingdom" if country=="UK"
kountry country, from(other) stuck
rename _ISO3N_ iso
gen double ym = (v2year*12)+(v3month)

// create central variables
gen Rue_retrench = 1 if v25policydomain==1 & (v8direction==1 | v21abolishment==1)
gen Rue_expand = 1 if v25policydomain==1 & (v8direction==3 | v22establishment==1)
gen Rue_visretrench = 1 if v25policydomain==1 & ((inlist(v7instrument,8,5,7,11,6) & v8direction==1) | v21abolishment==1)
gen Rue_visexpand = 1 if v25policydomain==1 & ((inlist(v7instrument,8,5,7,11,6) & v8direction==3) | v22establishment==1)

gen Rpen_retrench = 1 if v25policydomain==2 & (v8direction==1 | v21abolishment==1)
gen Rpen_expand = 1 if v25policydomain==2 & (v8direction==3 | v22establishment==1)
gen Rpen_visretrench = 1 if v25policydomain==2 & ((inlist(v7instrument,8,5,7,11,6) & v8direction==1) | v21abolishment==1)
gen Rpen_visexpand = 1 if v25policydomain==2 & ((inlist(v7instrument,8,5,7,11,6) & v8direction==3) | v22establishment==1)

gen Rwfs_retrench = cond(Rue_retrench==1 | Rpen_retrench==1,1,.)
gen Rwfs_expand = cond(Rue_expand==1 | Rpen_expand==1,1,.)
gen Rwfs_visretrench = cond(Rue_visretrench==1 | Rpen_visretrench==1,1,.)
gen Rwfs_visexpand = cond(Rue_visexpand==1 | Rpen_visexpand==1,1,.)

// restrict dataset to what is required
local indicators Rue_retrench Rue_expand Rpen_retrench Rpen_expand Rue_visretrench ///
Rue_visexpand Rpen_visretrench Rpen_visexpand Rwfs_retrench Rwfs_expand Rwfs_visretrench Rwfs_visexpand
local indlist
foreach x in `indicators' {
	local indlist `indlist' (sum) `x'
}
gcollapse `indlist', by(iso ym)
egen rnm = rownonmiss(`indicators')
drop if mi(iso) | mi(ym) | mi(rnm) | rnm==0
keep iso ym `indicators'

// reshape and save
reshape wide `indicators', i(iso) j(ym)
save "data/processed/reformevent_processed.dta", replace



*********************** CPDS DATA ******************************

use "data/raw/CPDS_1960-2019_Update_2021.dta",clear
drop iso
rename iso3n iso
rename socexp_t_pmp socspend
drop debt
rename debt_hist debt

// clean, reshape, and save
local CPDS_list unemp realgdpgr socspend debt deficit
keep iso year `CPDS_list'
reshape wide `CPDS_list',i(iso) j(year)
save "data/processed/cpds_processed.dta",replace






















