
*********************** LOAD DATA ******************************

clear all
use "data/processed/finaldata.dta",clear


*********************** PREPARATION ******************************

// normal model setup 
global cntrl 		days vote_share effnum_party unemp_avg Dunemp realgdpgr_avg Drealgdpgr deficit_y1
global modelopts 	vce(cluster gov_id party_id) a(time_fe)

// outreg opts
local x 	Dsocspend Duegen Dpengen Ruegen Rpengen
local int 	left left_alt clarity_dum low_pressure

local xvarlist
foreach v in `x' {
    if "`v'"=="Dsocspend" local xvarlist `xvarlist' `v' `v'_retr `v'_exp `v'_short `v'_short_retr `v'_short_exp
	if "`v'"!="Dsocspend" local xvarlist `xvarlist' `v' `v'_retr `v'_exp `v'_vis `v'_vis_retr `v'_vis_exp `v'_short `v'_short_retr `v'_short_exp
	
}
local interactlist
foreach v in `xvarlist' {
    foreach i in `int' {
		local interactlist `interactlist' c.`v'#c.`i'
	}
}

glob outregopts auto(2) label ctitle(" ") adjr2 addtext(Period FE, Yes) drop(time_*) sortvar(`xvarlist' `interactlist' `int' $cntrl )
	
	
*********************** REGRESSION COMMAND ******************************

capture program drop r
program r
	syntax , Yvar(string) Xvar(string) LEFTVar(string) PRESSUREVar(string) MOPTS(string) STORE(string) [CONTrol(string) CONDition(string)]
	
	// main regressions
	reghdfe `yvar' `xvar' `control' `condition', `mopts'
	outreg2 using "results/tables/`store'_`xvar'_main.doc", replace $outregopts
	margins, dydx(`xvar') post
	est save "results/estimates/`store'_`xvar'_m1", replace
	
	reghdfe `yvar' `xvar'_retr `xvar'_exp `control' `condition', `mopts'
	outreg2 using "results/tables/`store'_`xvar'_main.doc", append $outregopts
	margins, dydx(`xvar'_retr `xvar'_exp) post
	est save "results/estimates/`store'_`xvar'_m2", replace

	// most likely cases
	
	local no = -1
	local replace replace
	* interaction models
	foreach cond_int in `leftvar' clarity_dum low_`pressurevar' {
		local no = `no'+2
		if !(`"`condition'"'=="if `cond_int'==1") & ///
		!(("`cond_int'"=="low_`pressurevar'" | "`cond_int'"=="high_`pressurevar'") & ("`xvar'"=="Ruegen" | "`xvar'"=="Rpengen")) {
			reghdfe `yvar' c.`xvar'##c.`cond_int' `control' `condition', `mopts'
			outreg2 using "results/tables/`store'_`xvar'_interact.doc", `replace' $outregopts
			qui gen `xvar'`no' = `xvar'
			qui reghdfe `yvar' c.`xvar'`no'##c.`cond_int' `control' `condition', `mopts'
			margins, dydx(`xvar'`no') at(`cond_int'==1) post
			est save "results/estimates/`store'_`xvar'_l`no'", replace
			
			local no2 = `no'+1
			reghdfe `yvar' c.`xvar'_retr##c.`cond_int' c.`xvar'_exp c.`xvar'_exp#c.`cond_int' `control' `condition', `mopts'
			outreg2 using "results/tables/`store'_`xvar'_interact.doc", append $outregopts
			qui gen `xvar'_retr`no2' = `xvar'_retr
			qui gen `xvar'_exp`no2' = `xvar'_exp
			qui reghdfe `yvar' c.`xvar'_retr`no2'##c.`cond_int' c.`xvar'_exp`no2' c.`xvar'_exp`no2'#c.`cond_int' `control' `condition', `mopts'
			margins, dydx(`xvar'_retr`no2' `xvar'_exp`no2') at(`cond_int'==1) post
			est save "results/estimates/`store'_`xvar'_l`no2'", replace
			
			local replace append
		}
	}
	
	* visible changes
	* short-term and visible changes
	local replace replace
	foreach variant in short vis {
		local no = `no'+2
		if !(strpos(`"`xvar'"', "socspend") & "`variant'"=="vis") {
			reghdfe `yvar' c.`xvar'_`variant' `control' `condition', `mopts'
			outreg2 using "results/tables/`store'_`xvar'_visshort.doc", `replace' $outregopts
			qui gen `xvar'`no' = `xvar'_`variant'
			qui reghdfe `yvar' c.`xvar'`no' `control' `condition', `mopts'
			margins, dydx(`xvar'`no') post
			est save "results/estimates/`store'_`xvar'_l`no'", replace
			
			local no2 = `no'+1
			reghdfe `yvar' `xvar'_`variant'_retr `xvar'_`variant'_exp `control' `condition', `mopts'
			outreg2 using "results/tables/`store'_`xvar'_visshort.doc", append $outregopts
			qui gen `xvar'_retr`no2' = `xvar'_`variant'_retr
			qui gen `xvar'_exp`no2' = `xvar'_`variant'_exp
			qui reghdfe `yvar' `xvar'_retr`no2' `xvar'_exp`no2' `control' `condition', `mopts'
			margins, dydx(`xvar'_retr`no2' `xvar'_exp`no2') post
			est save "results/estimates/`store'_`xvar'_l`no2'", replace
			
			local replace append
		}
	}
	foreach dropno of numlist 1/`no2' {
		cap drop `xvar'`dropno'
		cap drop `xvar'_exp`dropno' `xvar'_retr`dropno'
	}
end


*********************** ESTIMATE REGRESSIONS ******************************	
	
// Main specifications
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange_pc) x(`var') cont($cntrl) leftv(left) pressurev(pressure) mopts($modelopts) store(mainspec)
}

// Robustness - only left parties
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange_pc) x(`var') cont($cntrl) leftv(left) pressurev(pressure) mopts($modelopts) store(r_onlyleft) cond(if left==1)
}

// Robustness - only high clarity of responsibility parties
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange_pc) x(`var') cont($cntrl) leftv(left) pressurev(pressure) mopts($modelopts) store(r_onlyclear) cond(if clarity_dum==1)
}

// Robustness - alternative left/right classifications 
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange_pc) x(`var') cont($cntrl) leftv(left_alt) pressurev(pressure) mopts($modelopts) store(r_rile)
}

// Robustness - excluding younger democracies 
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange_pc) x(`var') cont($cntrl) leftv(left) pressurev(pressure) mopts($modelopts) store(r_young) cond(if youngdem==0)
}

// Robustness - no control variables 
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange_pc) x(`var') leftv(left) pressurev(pressure) mopts(vce(cluster gov_id party_id) noab) store(r_nox)
}

// Robustness - normal dependent variable 
foreach var in Duegen Dpengen Dsocspend Ruegen Rpengen {
	r, y(votechange) cont($cntrl)  x(`var') leftv(left) pressurev(pressure) mopts($modelopts) store(r_normdv)
}


*********************** TABLE A1: SUMMARY STATISTICS ******************************	

outreg2 using "results/tables/sumstat.doc", replace sum(log) eqkeep(N mean median sd min max) auto(2) label ///
	keep(votechange_pc votechange `xvarlist' `int' $cntrl ) sortvar(votechange_pc votechange `xvarlist' `int' $cntrl ) 


*********************** CLEAN THE TABLE DIRECTORY ******************************

preserve
filelist, dir("results/tables")
gen file = subinstr(filename, ".txt", "", .)
levelsof file if substr(filename,-3,3)=="txt", local(txtfiles)
restore
foreach x in `txtfiles' {
    erase "results/tables/`x'.txt"
}














	



