*********************** LOAD DATA AND GRAPH PRESETS ******************************

clear all
use "data/processed/finaldata.dta",clear
run "scripts/99_figureoptions.do"


*********************** FIGURE 2: DISTRIBUTIONS OF WELFARE CHANGES ******************************

// changes to welfare type distributions
tw (kdensity Dsocspend, $mdensityopts1), $plg_mdensity title("") note("") xtitle("Social spending change",size(*1.15)) ///
		xlab(-4(2)4) ylab(0(.2).6) xline(0,lc(gs3) lp(longdash)) nodraw name(a,replace) ytitle("Density",size(*1.2))

tw (kdensity Duegen, $mdensityopts1) (kdensity Dpengen, $mdensityopts2), ///
	$plg_mdensity title("") legend(order(1 "Unemp." "benefits" 2 "Pensions") size(*.8) symx(*.6) colg(tiny) m(vtiny) ring(0) region(lc(black)) pos(1)) ///
	ylab(0(.2).8) xlab(-5(2.5)5) ytitle("") xtitle("Generosity change",size(*1.2)) ///
	xline(0,lc(gs3) lp(dash)) name(b,replace)

tw (hist Ruegen, $mhistopts1 discrete density) (hist Rpengen, $mhistopts2 discrete density), $plg_mhist name(c, replace) nodraw ///
	legend(off)	xlab(-2(1)2) xtitle("Net reform events",size(*1.2)) xline(0,lc(gs3) lp(dash)) ytitle("")
	
graph combine a b c, imargin(tiny) row(1) scale(*3) xsize(*2.5)
graph export "results/figures/Figure2.emf", replace
graph export "results/figures/Figure2.tif", replace width(3060)


*********************** FIGURES 3-5 AND A2-A19: COEFFICIENT PLOTS ******************************

// program to build inputs for coefplot
cap program drop plothelper 
program plothelper 
	syntax , MODEL(string) Xvar(string)
	
	// file lister
	preserve
	qui filelist, dir("results/estimates")
	qui gen file = subinstr(filename, ".ster", "", .)
	qui sort file
	qui levelsof file if strpos(file,"`model'_`xvar'"), local(savedmodels)
	restore
	est clear
	local no = 0
	foreach x in `savedmodels' {
		dis " `x' "
		est use "results/estimates/`x'.ster"
		est sto `x'
		local no = `no'+1
	}
		
	// model list 
	local minno = 1
	if  (`"`model'"'=="r_onlyleft") local minno = 3
	local count = 1
	glob plots (`model'_`xvar'_m1 , $m1 ) (`model'_`xvar'_m2 , $m2 )
	*glob plots
	qui est dir
	foreach number of numlist `minno'/20 {
	    if strpos(r(names), "`model'_`xvar'_l`number'") {
			if mod(`count',2)==1 glob plots $plots (`model'_`xvar'_l`number' , $m1 )
			if mod(`count',2)==0 glob plots $plots (`model'_`xvar'_l`number' , $m2 )
			local count = `count'+1
		}
	}
	
	// further options
	*labels 
	glob labels `xvar' = "Overall change" `xvar'_retr = "Retrenchment" `xvar'_exp = "Expansion"
	glob nolabels `xvar' = " " `xvar'_retr = " " `xvar'_exp = " "
	foreach numberi of numlist 1/20 {
		glob labels $labels `xvar'`numberi' = "Overall change" `xvar'_retr`numberi' = "Retrenchment" `xvar'_exp`numberi' = "Expansion"
		glob nolabels $nolabels `xvar'`numberi' = " " `xvar'_retr`numberi' = " " `xvar'_exp`numberi' = " "
	}
	*groups 
	#delimit ;
	glob groups 	`xvar' `xvar'_retr `xvar'_exp = "{bf:Overall}"
					`xvar'1 `xvar'_retr2 `xvar'_exp2 = `""{bf:Pro-welfare}" "{bf:parties}""' 
					`xvar'3 `xvar'_retr4 `xvar'_exp4 = `""{bf:High clarity of}" "{bf:responsibility}""'
					`xvar'5 `xvar'_retr6 `xvar'_exp6 = `""{bf:Low fiscal}" "{bf:pressure}""'
					`xvar'7 `xvar'_retr8 `xvar'_exp8 = `""{bf:Recent welfare}" "{bf:changes}""'
					`xvar'9 `xvar'_retr10 `xvar'_exp10 = `""{bf:Visible welfare}" "{bf:changes}""' ;
	
	glob nogroups 	`xvar' `xvar'_retr `xvar'_exp = " "
					`xvar'1 `xvar'_retr2 `xvar'_exp2 = " "
					`xvar'3 `xvar'_retr4 `xvar'_exp4 = " "
					`xvar'5 `xvar'_retr6 `xvar'_exp6 = " "
					`xvar'7 `xvar'_retr8 `xvar'_exp8 = " "
					`xvar'9 `xvar'_retr10 `xvar'_exp10 = " " ;
	#delimit cr
	glob singlegroups $groups

	glob comboplot1 $cpopts groups($groups) coeflabel($labels) nodraw name(a,replace)
	glob comboplot2 $cpopts ylab(,notick)	groups($nogroups) coeflabel($nolabels) nodraw name(b,replace)
	glob singleplot $cpopts groups($singlegroups) coeflabel($labels) 
end

// coefplot options
*options for all graphs
glob cpopts msize(*.8) level(95) $plg_coefplot legend(off) title(,size(*.8)) xlab(#6)
*size and scaling for the four different plot types
glob nogrcom xsize(*.8) scale(*1)
glob grcom xsize(*1) scale(*1.4) imargin(tiny)
glob s1 fxsize(145)
glob s2 fxsize(52)
*markers and CIs
glob m1 $cimarkers1 ciopts($cibars1) offset(0)
glob m2 $cimarkers2 ciopts($cibars2) offset(0)


// loop over all main and most robustness regressions

foreach model in mainspec r_onlyleft r_onlyclear r_young r_nox r_normdv {

	// social spending
	plothelper, model(`model') xvar(Dsocspend)
	coefplot $plots , $singleplot $nogrcom
	if "`model'"=="mainspec" {
		graph export "results/figures/Figure3.emf", replace
		graph export "results/figures/Figure3.eps", replace
	}
	else {
		graph export "results/figures/`model'_socspend.emf", replace
		graph export "results/figures/`model'_socspend.eps", replace
	}

	// generosity changes 
	plothelper, model(`model') xvar(Duegen)
	coefplot $plots , $comboplot1 title("{bf:Unemployment benefits}")
	plothelper, model(`model') xvar(Dpengen)
	coefplot $plots , $comboplot2 $s2 title("{bf:Pensions}")
	graph combine a b, $grcom
	if "`model'"=="mainspec" {
		graph export "results/figures/Figure4.emf", replace
		graph export "results/figures/Figure4.eps", replace
	}
	else {
		graph export "results/figures/`model'_generosity.emf", replace
		graph export "results/figures/`model'_generosity.eps", replace
	}

	// reform events
	plothelper, model(`model') xvar(Ruegen)
	coefplot $plots , $comboplot1 title("{bf:Unemployment benefits}")	
	plothelper, model(`model') xvar(Rpengen)
	coefplot $plots , $comboplot2 $s2 title("{bf:Pensions}")
	graph combine a b, $grcom
	if "`model'"=="mainspec" {
		graph export "results/figures/Figure5.emf", replace
		graph export "results/figures/Figure5.eps", replace
	}
	else {
		graph export "results/figures/`model'_reform.emf", replace
		graph export "results/figures/`model'_reform.eps", replace
	}
	
}


****** additional robustness test: alternative left-right ******	

// build different version of the plothelper program
cap program drop plothelper2
program plothelper2 
	syntax , MODEL(string) Xvar(string)
	
	// file lister
	preserve
	qui filelist, dir("results/estimates")
	qui gen file = subinstr(filename, ".ster", "", .)
	qui sort file
	qui levelsof file if strpos(file,"`model'_`xvar'_l"), local(savedmodels)
	restore
	est clear
	local no = 0
	foreach x in `savedmodels' {
		dis " `x' "
		est use "results/estimates/`x'.ster"
		est sto `x'
		local no = `no'+1
	}
		
	// model list 
	local count = 1
	if (`"`model'"'=="r_rile") local nlist 1 2
	if (`"`model'"'=="r_pressure") local nlist 5 6
	glob plots
	qui est dir
	
	foreach number of numlist `nlist' {
	    if strpos(r(names), "`model'_`xvar'_l`number'") {
			if mod(`count',2)==1 glob plots $plots (`model'_`xvar'_l`number' , $m1 )
			if mod(`count',2)==0 glob plots $plots (`model'_`xvar'_l`number' , $m2 )
			local count = `count'+1
		}
	}

	// most likely tests
	*labels 
	glob labels
	glob nolabels
	foreach numberi of numlist 1/20 {
		glob labels $labels `xvar'`numberi' = "Overall change" `xvar'_retr`numberi' = "Retrenchment" `xvar'_exp`numberi' = "Expansion"
		glob nolabels $nolabels `xvar'`numberi' = " " `xvar'_retr`numberi' = " " `xvar'_exp`numberi' = " "
	}
	*groups 
	#delimit ;
	glob groups 	`xvar'1 `xvar'_retr2 `xvar'_exp2 = `""{bf:Pro-welfare parties}" "{bf:(including CDs)}""' 
					`xvar'5 `xvar'_retr6 `xvar'_exp6 = `""{bf:Low unemp-}" "{bf:loyment}""' ;
	
	glob nogroups 	`xvar'1 `xvar'_retr2 `xvar'_exp2 = " "
					`xvar'3 `xvar'_retr4 `xvar'_exp4 = " "
					`xvar'5 `xvar'_retr6 `xvar'_exp6 = " "
					`xvar'7 `xvar'_retr8 `xvar'_exp8 = " "
					`xvar'9 `xvar'_retr10 `xvar'_exp10 = " "
					`xvar'11 `xvar'_retr12 `xvar'_exp12 = " " ;
	#delimit cr
	glob singlegroups $groups
	
	glob comboplot1 $cpopts groups($groups) coeflabel($labels) nodraw name(a,replace)
	glob comboplot2 $cpopts ylab(,notick)	groups($nogroups) coeflabel($nolabels) nodraw name(b,replace)
	glob singleplot $cpopts groups($singlegroups) coeflabel($labels) 
end


// coefplot options
*options for all graphs
glob cpopts msize(*.8) level(95) $plg_coefplot legend(off) title(,size(*.8)) xlab(#6)
*size and scaling for the four different plot types
glob nogrcom xsize(*1.8) scale(*2.2)
glob grcom xsize(*1.7) scale(*2.5) imargin(small)
glob s2 fxsize(90)
*markers and CIs
glob m1 $cimarkers1 ciopts($cibars1) offset(0)
glob m2 $cimarkers2 ciopts($cibars2) offset(0)


// loop over additional robustness models
foreach model in r_rile  {
    
	// social spending
	plothelper2, model(`model') xvar(Dsocspend)
	coefplot $plots , $singleplot $nogrcom
	graph export "results/figures/`model'_socspend.emf", replace

	// generosity changes 
	plothelper2, model(`model') xvar(Duegen)
	coefplot $plots , $comboplot1 title("{bf:Unemployment benefits}")
	plothelper2, model(`model') xvar(Dpengen)
	coefplot $plots , $comboplot2 $s2 title("{bf:Pensions}")
	graph combine a b, $grcom
	graph export "results/figures/`model'_generosity.emf", replace

	// reform events
	if !("`model'"=="r_pressure") {
		plothelper2, model(`model') xvar(Ruegen)
		coefplot $plots , $comboplot1 title("{bf:Unemployment benefits}")	
		plothelper2, model(`model') xvar(Rpengen)
		coefplot $plots , $comboplot2 $s2 title("{bf:Pensions}")
		graph combine a b, $grcom
		graph export "results/figures/`model'_reform.emf", replace
	}
}


*********************** FIGURE A1: OUTLIER VALUES ******************************

glob xlineopts lc(navy) lw(medium)
hist votechange_pc_ol, $plg_hist xlab(-100(50)200) width(10) xline(120, $xlineopts) xtitle("Vote change") gap(10) scale(*1.4) xsize(*1.2)
graph export "results/figures/outliers.emf", replace




















































