********************************************************************************
// 					   STATA FIGURE PRESETS
// 							Leo Ahrens
********************************************************************************

**************************  IMPORTANT  *****************************************

// Adjust this to where you unpacked all the files
global grdir C:/Forschung/Leo Stata Files/Plotplain graph presets

/* Tutorial
This dofile supplies presets for commonly used Stata figures. It is a weird mix 
between a collection of figure presets and a pretend graph scheme. 

Please replace the file path behind the "grdir" global (see above) with the path 
where you unpacked the ZIP file; and please install the required ados (see below).

The following section ("OPTIONS"") only contains options for all figure presets
(saved as locals and globals). If you do not want to change the overall look and 
color scheme of the figures, ignore this.

The interesting sections begin below the "OPTIONS" section (starting with 
"DESCRIPTIVE STATS PLOTS"). The executable code in these sections also only saves 
options in the form of globals for subsequent use. But the commented code in 
these sections contains presets and example plots of a wide range of figure types.

The intended use of this file is to run it once before creating your figures 
(e.g. by using the "run"/"use" commands in your analysis dofiles). Running this 
file will not execute any "real" command - it only stores figure options. Once 
you have run this file, you can copy one of the figure presets below and adjust 
it to your liking, primarily by substituting in your required variable names. 
To check what the figures look like, please load the example datasets beforehand
(i.e. execute the "use ..." commands in the example sections).  */

// Required ados
*ssc install blindschemes, replace
*ssc install palettes, replace
*ssc install colrspace, replace


**************************   OPTIONS   *****************************************

// General options for all graphs
glob axisgridopts labs(*1.05) tlc(black) tlw(thin) glc(gs13) glp(solid) glw(thin) gmin gmax
glob axislineopts lp(dash) lc(gs5) lw(thin)

glob plottig scheme(plotplain) graphregion(lc(white) lw(vthick)) ///
	ysc(lc(black) lw(thin)) xsc(lc(black) lw(thin)) ///
	ylab(, $axisgridopts)  ///
	xlab(, $axisgridopts)  ///
	title(,size(medium))
	
glob plottig_bar scheme(plotplain) ///
	ysc(lc(black) lw(thin)) ylab(, $axisgridopts) ///
	title(,size(medium)) intensity(*1.2)

// Color scheme
local colorscheme Set1
local colorschemeopts int(1.8)

qui colorpalette `colorscheme', `colorschemeopts' nograph local(,prefix(c))
foreach i of numlist 5(5)95 {
	qui colorpalette `colorscheme', `colorschemeopts' op(`i') nograph local(,prefix(c) suffix(o`i')) 
}
qui colorpalette `colorscheme', int(2.5) nograph local(,prefix(c) suffix(dark)) 
qui colorpalette `colorscheme', int(6) nograph local(,prefix(c) suffix(vdark)) 

// Frequently required suboptions
foreach i of numlist 1/8 {
	glob ciareas`i' lw(none) fc(`c`i'o30')
	glob cimarkers`i' mc(`c`i'')
	glob cibars`i' lcol(`c`i'') lw(medium) msize(*.5)
	glob lines`i' lp(solid) lc(`c`i'') lw(medthick)
	glob tsmarkers`i' mc(`c`i'') lc(`c`i'') lp(solid)
	glob alttsmarkers`i' mfc(`c`i'') mlc(black) mlw(vthin) mlalign(outside) lc(`c`i'vdark') lp(solid) lw(thin)
	
	glob fullscatterm`i' m(o) mfc(`c`i'o50') mlc(`c`i'')
	foreach h of numlist 25 50 75 {
	    glob scatter`h'm`i' m(o) mfc(`c`i'o`h'') mlalign(outside) mlw(none)
	}
}
glob altcibars lcol(black) lw(medthin) msize(*.5)

foreach g in tsmarkers alttsmarkers {
	glob `g'1 $`g'1 m(s) msize(*.7) 
	glob `g'2 $`g'2 m(o) msize(*.8)
	glob `g'3 $`g'3 m(d) msize(*.7) 
}
glob cimarkers1 $cimarkers1 m(O) msize(*.75)
glob cimarkers2 $cimarkers2 m(S) msize(*.65)
glob cimarkers3 $cimarkers3 m(D) msize(*.65)

glob legendop legend(region(lc(white)) pos(3) size(*1.05)) // für drinnen: legend(ring(0) region(lc(black)))


********************* DESCRIPTIVE STATS PLOTS **********************************

// kernel density plot
glob plg_density $plottig lalign(outside) recast(area) lc(black) lw(thin) fc(`c1o70') note("")
glob plg_mdensity $plottig $legendop note("")
glob mdensityopts1 lalign(outside) recast(area) lc(`c1dark') lw(thin) fc(`c1o60')
foreach i of numlist 2/5 {
	glob mdensityopts`i' lalign(outside) recast(area) lc(`c`i'dark') lw(thin) fc(`c`i'o30')
}

	/* 	Examples
	use "$grdir/essdata",clear
	kdensity age, $plg_density title("") note("")
	tw (kdensity age if emp==1, $mdensityopts1) (kdensity age if emp==4, $mdensityopts2), ///
		$plg_mdensity title("") legend(order(1 "Employed" 2 "Not in labor force"))
	*/

	
// histogram
glob plg_hist $plottig lalign(inside) lc(black) lw(thin) fc(`c1') 
glob plg_mhist $plottig $legendop
glob mhistopts1  lalign(inside) lc(`c1o10') lw(thin) fc(`c1o90')
foreach i of numlist 2/5 {
	glob mhistopts`i'  lalign(inside) lc(`c`i'o10') lw(thin) fc(`c`i'o50')
}

	/* 	Examples
	use "$grdir/essdata",clear
	hist age, $plg_hist
	tw (hist age if emp==1, $mhistopts1 width(2)) (hist age if emp==3, $mhistopts2 width(2)), $plg_mhist legend(order(1 "Employee" 2 "Unemployed"))
	*/
	
	
// bar graph
glob plg_bar $plottig_bar bar(1,fc(`c1') lc(black)) bar(2,fc(`c2') lc(black)) bar(3,fc(`c3') lc(black)) bar(4,fc(`c4') lc(black)) $legendop
glob plg_bar_xax axis(lcolor(none))

	/* 	Examples
	use "$grdir/essdata",clear
	graph bar, over(educ,lab(ang(25)) $plg_bar_xax) $plg_bar
	graph bar (mean) pinc_gross, over(gender) over(educ,lab(ang(25)) $plg_bar_xax) asyvars $plg_bar b1title("Education") bargap(10)
	*/
	
	
********************* SCATTERPLOTS + FITPLOTS **********************************
	
// scatterplot

	/* 	Examples
	use "$grdir/essdata",clear
	scatter pinc_gross eduyrs, $plottig $scatter50m2
	*/
	
// scatterplot with several colors
glob plg_mscatter $plottig $legendop

	/* 	Examples
	use "$grdir/essdata",clear
	sum eduyrs,d
	gen aboveaverage = cond(eduyrs>=r(p50),1,0) if !mi(eduyrs) & !mi(pinc_gross)
	tw (scatter pinc_gross eduyrs if aboveaverage==0, $scatter50m1) (scatter pinc_gross eduyrs if aboveaverage==1, $scatter50m3), $plg_mscatter
	*/

	
// scatterplot with linear fit
glob plg_lfit clp(solid) clc(`c1') clw(medthick)
glob plg_lfit2 $plottig $legendop legend(order(1 "Observed values" 2 "Linear fit")) 

	/* 	Examples
	use "$grdir/essdata",clear
	tw (scatter pinc_gross eduyrs, $scatter50m2) (lfit pinc_gross eduyrs, $plg_lfit), $plg_lfit2
	*/

	
// scatterplot with several fits and colors
glob plg_mscatter2 $plottig $legendop legend(order(1 "Observed values" 2 "Observed values" 3 "Linear fit" 4 "Linear fit")) 
foreach x of numlist 1/9 {
	glob plg_mlfit`x' clp(solid) clc(`c`x'dark') clw(medthick)
}

	/* 	Examples
	use "$grdir/essdata",clear
	sum eduyrs,d
	gen aboveaverage = cond(eduyrs>=r(p50),1,0) if !mi(eduyrs) & !mi(pinc_gross)
	tw 	(scatter pinc_gross eduyrs if aboveaverage==0, $scatter50m1) ///
		(scatter pinc_gross eduyrs if aboveaverage==1, $scatter50m3) ///
		(lfit pinc_gross eduyrs if aboveaverage==0, $plg_mlfit1) ///
		(lfit pinc_gross eduyrs if aboveaverage==1, $plg_mlfit3), $plg_mscatter2
	*/

	
// scatterplot with linear fit and CIs
glob plg_lfitci acol(`c1o50') alw(none) clp(solid) clc(`c1') clw(medthick)
glob plg_lfitci2 $plottig $legendop legend(order(1 "Observed values" 3 "Linear fit" 2 "95% CIs")) 

	/* 	Examples
	use "$grdir/essdata",clear
	tw (scatter pinc_gross eduyrs, $scatter50m2) (lfitci pinc_gross eduyrs, $plg_lfitci), $plg_lfitci2
	*/

	
// scatterplot with local polynominal fit and CIs
glob plg_pfitci acol(`c1o50') alw(none) clp(solid) clc(`c1') clw(medthick)
glob plg_pfitci2 $plottig $legendop legend(order(1 "Observed values" 3 "Local polynominal fit" 2 "95% CIs")) 

	/* 	Examples
	use "$grdir/essdata",clear
	tw (scatter pinc_gross age, $scatter50m2) (lpolyci pinc_gross age, $plg_pfitci bwidth(7)), $plg_pfitci2
	*/	
	
	
*************************** MARGINSPLOTS ***************************************
	
// marginsplot (linear prediction)
glob plg_linmarg $plottig recast(line) recastci(rarea) plotopts($lines1) ciopts($ciareas1)

	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross eduyrs
	margins,at(eduyrs=(8(2)30))
	marginsplot, $plg_linmarg title("") 
	*/
	
	
// marginsplot (multiple linear predictions)
glob plg_multilinmarg $plottig recast(line) recastci(rarea) ///
	plot1opts($lines1) ci1opts($ciareas1) plot2opts($lines2) ci2opts($ciareas2) ///
	$legendop
	
	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross eduyrs i.gender
	margins,at(eduyrs=(8(2)30)) over(gender)
	marginsplot, $plg_multilinmarg title("") 
	*/
	
	
// marginsplot (linear prediction with histogram)
glob plg_linhistmarg $plg_linmarg $legendop
glob plg_linhistmarg2 $plottig fc(`c2o50') lc(%50) gap(10) yaxis(2) ysc(axis(2) noline) ylab(none,axis(2)) ytitle("",axis(2)) legend(order(2 "Prediction" 1 "95% CIs" 3 "Empirical distribution"))

	/* 	Examples
	use "$grdir/essdata",clear
	drop if eduyrs<8
	reg pinc_gross eduyrs
	margins,at(eduyrs=(8(2)30))
	marginsplot, addplot(hist eduyrs, $plg_linhistmarg2 discrete xlab(8(2)30) ysc(r(0 .7) axis(2))) $plg_linhistmarg title("")
	*/
	
	
// marginsplot (linear predictions with scatterplot)
glob plg_linscattermarg $plg_linmarg $legendop
glob plg_linscattermarg2 $plottig $scatter50m2 legend(order(2 "Prediction" 1 "95% CIs" 3 "Observed values")) below

	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross eduyrs
	margins,at(eduyrs=(0(5)30))
	marginsplot, addplot(scatter pinc_gross eduyrs, $plg_linscattermarg2) $plg_linscattermarg title("")
	*/

	
// marginsplot (categorical prediction)
glob plg_catmarg $plottig recast(scatter) recastci(rcap) plotopts($cimarkers1) ciopts($cibars1)

	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross i.educ
	margins,over(educ)
	marginsplot, $plg_catmarg title("") xlab(,angle(20)) xsc(r(.8 6.2))
	*/

// marginsplot (categorical prediction with scatterplot)
glob plg_catscattermarg $plg_catmarg $legendop
glob plg_catscattermarg2 $plottig $scatter25m2 legend(order(2 "Prediction" 1 "95% CIs" 3 "Observed values")) below

	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross i.educ
	margins,over(educ)
	marginsplot, addplot(scatter pinc_gross educ, $plg_catscattermarg2 jitter(7) xsc(r(.5 6.5))) $plg_catscattermarg title("") xlab(,angle(20))
	*/
	
	
// marginsplot (marginal effect of X after interaction with numerical variable Z)
glob plg_linintmarg $plottig recast(line) recastci(rarea) plotopts($lines1) ciopts($ciareas1) ///
	yline(0, $axislineopts )
	
	/* 	Examples
	use "$grdir/essdata",clear
	reg redistr c.eduyrs##c.pinc_gross
	margins,dydx(pinc_gross) at(eduyrs=(0(2)30))
	marginsplot, $plg_linintmarg title("")
	*/	

	
// marginsplot (marginal effect of X after interaction - histogram version)
glob plg_lininthistmarg $plottig recast(line) recastci(rarea) plotopts($lines1) ciopts($ciareas1) ///
	yline(0,$axislineopts) $legendop
	
	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross c.eduyrs##c.age
	margins,dydx(eduyrs) at(age=(15(15)90))
	marginsplot, addplot(hist age, $plg_linhistmarg2 ysc(axis(2) r(0 .17)) ylab(-100(100)600) xlab(15(5)90)) $plg_lininthistmarg title("") 
	*/	

	
	
************************ TIME SERIES PLOTS *************************************

glob plg_mtslineopts $plottig $legendop

// time series plot - line

	/* 	Examples
	use "$grdir/cpdsdata",clear
	line debt year if iso=="DEU", $plottig $lines1
	tw (line debt year if iso=="DEU", $lines1) (line debt year if iso=="NLD", $lines2), $plg_mtslineopts
	*/

	
// time series plot - connected

	/* 	Examples
	use "$grdir/cpdsdata",clear
	tw (connected debt year if iso=="DEU", $tsmarkers1), $plottig 
	tw (connected debt year if iso=="DEU", $tsmarkers1) (connected debt year if iso=="NLD", $tsmarkers2), $plg_mtslineopts
	*/

	
// time series plot - connected with outlines

	/* 	Examples
	use "$grdir/cpdsdata",clear
	tw (connected debt year if iso=="DEU", $alttsmarkers1), $plottig 
	tw (connected debt year if iso=="DEU", $alttsmarkers1) (connected debt year if iso=="NLD", $alttsmarkers2), $plg_mtslineopts
	*/
	
	
// time series in subplots - line
glob plg_ctsbyopts subtitle(, fcolor(`c7o10') justification(center) alignment(middle))
	
	/* 	Examples
	use "$grdir/cpdsdata",clear
	line debt year, by(iso,note("")) $plottig $lines1 $plg_ctsbyopts
	tw (line debt year, $lines1) (line deficit year, $lines2), by(iso,note("")) $plottig $plg_ctsbyopts legend(pos(6)) 
	*/

	
// time series in subplots - connected
	
	/* 	Examples
	use "$grdir/cpdsdata",clear
	tw (connected debt year, by(iso,note("")) $tsmarkers1 msize(*.4)), $plottig $plg_ctsbyopts
	tw (connected debt year, $tsmarkers1 msize(*.4)) (connected deficit year, $tsmarkers2 msize(*.4)), by(iso,note("")) $plottig $plg_ctsbyopts legend(pos(6)) 
	*/
	

************************ COEFFICIENT PLOTS *************************************
	
// simple coefficient plot
glob plg_coefplot $plottig xline(0,$axislineopts) plotregion(margin(tiny))  /// 
	ysc(noline) ylab(, tlc(gs13)) grid(within glp(solid) glw(thin) glc(gs13) nogextend) xlab(,gextend)

	/* 	Examples
	use "$grdir/essdata",clear
	reg pinc_gross i.educ age i.emp
	est sto model
	
	coefplot ///
	(model, $cimarkers1 ciopts($cibars1)), ///
	$plg_coefplot drop(_cons) ysc(r(.5 6.5)) ///
	ysize(9) xsize(20) scale(*1.5) ///
	xtitle("Effect on personal gross income")
	*/	
	
	
	
// event study DID plot
glob axislinestyle lp(dash) lc(gs5) lw(thin)
glob plg_eventstudy $plottig base vertical legend(off) offset(0)   ///
	yline(0, $axislinestyle) xlab(,grid glc(gs13))  ///
	recast(connected) $tsmarkers1
glob plg_eventstudy2 ciopts(recast(rarea) lc(`c1o15') fc(`c1o25'))

/* Examples 
use "$grdir/cpdsdata",clear

local minyear = 2004
local maxyear = 2014
local treatyear = 2009

gen diddummy = cond(iso3n>392,1,0) if inrange(year,`minyear',`maxyear')
gen timedummy = cond(year>=`treatyear',1,0) if inrange(year,`minyear',`maxyear')

tempvar did_timedummy
gen `did_timedummy' = diddummy*timedummy
foreach x in diddummy timedummy {
replace `x'= . if mi(`did_timedummy')
}

by iso3n: gen did_0 = cond(`did_timedummy'==1 & `did_timedummy'[_n-1]==0,1,0) if !mi(`did_timedummy')

foreach i of numlist 1/5 {
    by iso3n: gen did_minus`i' = cond(did_0[_n+`i']==1,1,0) if !mi(`did_timedummy')
	by iso3n: gen did_plus`i' = cond(did_0[_n-`i']==1,1,0) if !mi(`did_timedummy')
}

xtreg debt c.diddummy##ib2009.year ,fe vce(r)
est sto eventstudy

#delimit ;
	coefplot 
	(eventstudy, $plg_eventstudy2 ), 
	rename(	2004.year#c.diddummy="t-5"	2005.year#c.diddummy="t-4" 
			2006.year#c.diddummy="t-3"	2007.year#c.diddummy="t-2"
			2008.year#c.diddummy="t-1"	2009.year="t"
			2010.year#c.diddummy="t+1"	2011.year#c.diddummy="t+2"
			2012.year#c.diddummy="t+3"	2013.year#c.diddummy="t+4"
			2014.year#c.diddummy="t+5") 
	order(	2004.year#c.diddummy="t-5"	2005.year#c.diddummy="t-4" 
			2006.year#c.diddummy="t-3"	2007.year#c.diddummy="t-2"
			2008.year#c.diddummy="t-1"	2009.year="t")
	$plg_eventstudy 
	keep(2009.year *.year#c.diddummy *.year#co.diddummy) 
	xline(6, $axislinestyle)
	ysize(12) xsize(20) scale(*1.2)
	;
#delimit cr

*/







	
	
	
	
	
	
	
	
	
	
	
	
	
	